@@ -1,7 +1,7 @@
 /* prott.c
    The 't' protocol.
 
-   Copyright (C) 1991, 1992 Ian Lance Taylor
+   Copyright (C) 1991, 1992, 2002 Ian Lance Taylor
 
    This file is part of the Taylor UUCP package.
 
@@ -17,16 +17,15 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307, USA.
 
-   The author of the program may be contacted at ian@airs.com or
-   c/o Cygnus Support, 48 Grove Street, Somerville, MA 02144.
+   The author of the program may be contacted at ian@airs.com.
    */
 
 #include "uucp.h"
 
 #if USE_RCS_ID
-const char prott_rcsid[] = "$Id: prott.c,v 1.29 1995/06/21 19:15:36 ian Rel $";
+const char prott_rcsid[] = "$Id: prott.c,v 1.32 2002/03/05 19:10:41 ian Rel $";
 #endif
 
 #include "uudefs.h"
@@ -98,7 +97,7 @@ ftstart (qdaemon, pzlog)
 /*ARGSUSED*/
 boolean 
 ftshutdown (qdaemon)
-     struct sdaemon *qdaemon;
+     struct sdaemon *qdaemon ATTRIBUTE_UNUSED;
 {
   xfree ((pointer) zTbuf);
   zTbuf = NULL;
@@ -115,8 +114,8 @@ boolean
 ftsendcmd (qdaemon, z, ilocal, iremote)
      struct sdaemon *qdaemon;
      const char *z;
-     int ilocal;
-     int iremote;
+     int ilocal ATTRIBUTE_UNUSED;
+     int iremote ATTRIBUTE_UNUSED;
 {
   size_t clen, csend;
   char *zalc;
@@ -147,7 +146,7 @@ ftsendcmd (qdaemon, z, ilocal, iremote)
 /*ARGSIGNORED*/
 char *
 ztgetspace (qdaemon, pclen)
-     struct sdaemon *qdaemon;
+     struct sdaemon *qdaemon ATTRIBUTE_UNUSED;
      size_t *pclen;
 {
   *pclen = CTBUFSIZE;
@@ -164,9 +163,9 @@ ftsenddata (qdaemon, zdata, cdata, ilocal, iremote, ipos)
      struct sdaemon *qdaemon;
      char *zdata;
      size_t cdata;
-     int ilocal;
-     int iremote;
-     long ipos;
+     int ilocal ATTRIBUTE_UNUSED;
+     int iremote ATTRIBUTE_UNUSED;
+     long ipos ATTRIBUTE_UNUSED;
 {
   /* Here we do htonl by hand, since it doesn't exist everywhere.  We
      know that the amount of data cannot be greater than CTBUFSIZE, so
@@ -315,11 +314,11 @@ ftwait (qdaemon)
 /*ARGSUSED*/
 boolean
 ftfile (qdaemon, qtrans, fstart, fsend, cbytes, pfhandled)
-     struct sdaemon *qdaemon;
-     struct stransfer *qtrans;
+     struct sdaemon *qdaemon ATTRIBUTE_UNUSED;
+     struct stransfer *qtrans ATTRIBUTE_UNUSED;
      boolean fstart;
      boolean fsend;
-     long cbytes;
+     long cbytes ATTRIBUTE_UNUSED;
      boolean *pfhandled;
 {
   *pfhandled = FALSE;
