@@ -81,14 +81,14 @@
  *    'a', or maybe in time this will be *the* 'z' protocol.
  *
  * 8) Since we are writing a transport protocol, which isn't supposed to know
- *    anything about what is being transfered or where it is coming from, the
+ *    anything about what is being transferred or where it is coming from, the
  *    header data value has changed meaning. It no longer means "file position"
  *    but instead means "window position". It is a running counter of the bytes
- *    transfered. Each "message" begins on a 1k boundary so the count isn't a
+ *    transferred. Each "message" begins on a 1k boundary so the count isn't a
  *    precise byte count. The counter wraps every 4 gigabytes, although this
  *    wrapping isn't supported yet.
  *
- *    FIXME: At present the max data transfered per session is 4 gigabytes.
+ *    FIXME: At present the max data transferred per session is 4 gigabytes.
  *
  ****************************************************************************
  *
@@ -181,7 +181,7 @@
 #include "uucp.h"
 
 #if USE_RCS_ID
-const char protz_rcsid[] = "$Id: protz.c,v 1.8 1993/12/20 00:44:49 ian Rel $";
+const char protz_rcsid[] = "$Id: protz.c,v 1.11 2002/02/08 10:35:52 ian Rel $";
 #endif
 
 #include <errno.h>
@@ -451,7 +451,7 @@ static const char *azZframe_types[] = {
 #define min(a, b)	((a) < (b) ? (a) : (b))
 #endif
 #define ZZHEADER_NAME(itype) \
-		azZframe_types[min((itype) + FTOFFSET, FTNUMBER - 1)]
+		azZframe_types[min((size_t) ((itype) + FTOFFSET), FTNUMBER - 1)]
 
 /*
  * Local functions ...
@@ -672,8 +672,8 @@ boolean
 fzsendcmd(qdaemon, z, ilocal, iremote)
 struct sdaemon *qdaemon;
 const char *z;
-int ilocal;
-int iremote;
+int ilocal ATTRIBUTE_UNUSED;
+int iremote ATTRIBUTE_UNUSED;
 {
 	size_t n,clen;
 	long lredo;
@@ -720,7 +720,7 @@ int iremote;
 /*ARGSUSED*/
 char *
 zzgetspace(qdaemon, pclen)
-struct sdaemon *qdaemon;
+struct sdaemon *qdaemon ATTRIBUTE_UNUSED;
 size_t *pclen;
 {
 	*pclen = cZblklen;
@@ -739,9 +739,9 @@ fzsenddata(qdaemon, zdata, cdata, ilocal, iremote, ipos)
 struct sdaemon *qdaemon;
 char *zdata;
 size_t cdata;
-int ilocal;
-int iremote;
-long ipos;
+int ilocal ATTRIBUTE_UNUSED;
+int iremote ATTRIBUTE_UNUSED;
+long ipos ATTRIBUTE_UNUSED;
 {
 	DEBUG_MESSAGE1 (DEBUG_PROTO, "fzsenddata: %d bytes", cdata);
 
@@ -784,7 +784,7 @@ boolean fendofmessage;
 		iZlast_tx_data_packet = ZCRCW;
 	else if (wpZtxpos == wpZlastsync)
 		iZlast_tx_data_packet = ZCRCW;
-	else if (cZrx_buf_len && (cZrxwcnt += n) >= cZrx_buf_len)
+	else if (cZrx_buf_len && (cZrxwcnt += n) >= (size_t) cZrx_buf_len)
 		iZlast_tx_data_packet = ZCRCW;
 	else if ((cZtxwcnt += n) >= cZtxwspac) {
 		iZlast_tx_data_packet = ZCRCQ;
@@ -802,7 +802,7 @@ boolean fendofmessage;
 #endif
 		if (cZblklen > 1024)
 			cZblklen = 1024;
-		if (cZrx_buf_len && cZblklen > cZrx_buf_len)
+		if (cZrx_buf_len && cZblklen > (size_t) cZrx_buf_len)
 			cZblklen = cZrx_buf_len;
 	}
 
@@ -868,7 +868,7 @@ boolean fendofmessage;
 	 * I use (cZtx_window - 2048) to play it safe.
 	 */
 
-	while (wpZtxpos - wpZlrxpos >= cZtx_window - 2048) {
+	while (wpZtxpos - wpZlrxpos >= (size_t) cZtx_window - 2048) {
 		if (iZlast_tx_data_packet != ZCRCQ) {
 		    if (!fzsend_data_packet (qdaemon, zdata, (size_t) 0,
 					     iZlast_tx_data_packet = ZCRCQ,
@@ -1194,8 +1194,6 @@ moredata:
 			return FALSE;
 		}
 	}
-
-	return TRUE;
 }
 
 /*
@@ -1213,7 +1211,7 @@ struct sdaemon *qdaemon;
 struct stransfer *qtrans;
 boolean fstart;
 boolean fsend;
-long cbytes;
+long cbytes ATTRIBUTE_UNUSED;
 boolean *pfhandled;
 {
 	long iredo;
