@@ -1,7 +1,7 @@
 /* cusub.c
    System dependent routines for cu.
 
-   Copyright (C) 1992, 1993, 1995 Ian Lance Taylor
+   Copyright (C) 1992, 1993, 1995, 2002 Ian Lance Taylor
 
    This file is part of the Taylor UUCP package.
 
@@ -17,16 +17,15 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307, USA.
 
-   The author of the program may be contacted at ian@airs.com or
-   c/o Cygnus Support, 48 Grove Street, Somerville, MA 02144.
+   The author of the program may be contacted at ian@airs.com.
    */
 
 #include "uucp.h"
 
 #if USE_RCS_ID
-const char cusub_rcsid[] = "$Id: cusub.c,v 1.24 1995/06/21 19:18:53 ian Rel $";
+const char cusub_rcsid[] = "$Id: cusub.c,v 1.27 2002/03/05 19:10:42 ian Rel $";
 #endif
 
 #include "uudefs.h"
@@ -374,7 +373,7 @@ volatile sig_atomic_t fScu_alarm;
 
 static RETSIGTYPE
 uscu_alarm (isig)
-     int isig;
+     int isig ATTRIBUTE_UNUSED;
 {
 #if ! HAVE_SIGACTION && ! HAVE_SIGVEC && ! HAVE_SIGSET
   (void) signal (isig, uscu_alarm);
@@ -448,7 +447,7 @@ static volatile sig_atomic_t iSsend_sig;
 
 static RETSIGTYPE
 uscu_alarm_kill (isig)
-     int isig;
+     int isig ATTRIBUTE_UNUSED;
 {
 #if ! HAVE_SIGACTION && ! HAVE_SIGVEC && ! HAVE_SIGSET
   (void) signal (isig, uscu_alarm_kill);
@@ -639,7 +638,9 @@ uscu_child (qconn, opipe)
   cwrite = 0;
 
   if (fsysdep_catch ())
-    usysdep_start_catch ();
+    {
+      usysdep_start_catch ();
+    }
 
   while (TRUE)
     {
