@@ -1,7 +1,7 @@
 /* jobid.c
    Convert file names to jobids and vice versa.
 
-   Copyright (C) 1991, 1992, 1995 Ian Lance Taylor
+   Copyright (C) 1991, 1992, 1995, 2002 Ian Lance Taylor
 
    This file is part of the Taylor UUCP package.
 
@@ -17,10 +17,9 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307, USA.
 
-   The author of the program may be contacted at ian@airs.com or
-   c/o Cygnus Support, 48 Grove Street, Somerville, MA 02144.
+   The author of the program may be contacted at ian@airs.com.
    */
 
 #include "uucp.h"
@@ -37,7 +36,7 @@ char *
 zsfile_to_jobid (qsys, zfile, bgrade)
      const struct uuconf_system *qsys;
      const char *zfile;
-     int bgrade;
+     int bgrade ATTRIBUTE_UNUSED;
 {
   size_t clen;
   char *zret;
