@@ -1,7 +1,7 @@
 /* lock.c
    Lock and unlock a file name.
 
-   Copyright (C) 1991, 1992, 1993 Ian Lance Taylor
+   Copyright (C) 1991, 1992, 1993, 1995, 2002 Ian Lance Taylor
 
    This file is part of the Taylor UUCP package.
 
@@ -17,16 +17,15 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307, USA.
 
-   The author of the program may be contacted at ian@airs.com or
-   c/o Cygnus Support, Building 200, 1 Kendall Square, Cambridge, MA 02139.
+   The author of the program may be contacted at ian@airs.com.
    */
 
 #include "uucp.h"
 
 #if USE_RCS_ID
-const char lock_rcsid[] = "$Id: lock.c,v 1.15 1994/01/30 21:09:20 ian Rel $";
+const char lock_rcsid[] = "$Id: lock.c,v 1.23 2002/03/05 19:10:42 ian Rel $";
 #endif
 
 #include "uudefs.h"
@@ -34,6 +33,7 @@ const char lock_rcsid[] = "$Id: lock.c,v 1.15 1994/01/30 21:09:20 ian Rel $";
 #include "system.h"
 
 #include <errno.h>
+#include <ctype.h>
 
 #if HAVE_FCNTL_H
 #include <fcntl.h>
@@ -178,7 +178,7 @@ fsdo_lock (zlock, fspooldir, pferr)
     }
 
 #if HAVE_QNX_LOCKFILES
-  sprintf (ab, "%10ld %10ld\n", (long) ime, (long) inid);
+  sprintf (ab, "%10ld %10ld\n", (long) ime, (long) inme);
   cwrote = write (o, ab, strlen (ab));
 #else
 #if HAVE_V2_LOCKFILES
@@ -274,6 +274,25 @@ fsdo_lock (zlock, fspooldir, pferr)
 	  break;
 	}
 
+#if DEBUG > 0
+#if HAVE_V2_LOCKFILES
+      {
+	char ab[10];
+
+	if (read (o, ab, sizeof ab) > 4
+	    && isdigit (BUCHAR (ab[0])))
+	  ulog (LOG_ERROR,
+		"Lock file %s may be HDB format; check LOCKFILES in policy.h",
+		zpath);
+      }
+#else
+      if (cgot == 4)
+	ulog (LOG_ERROR,
+	      "Lock file %s may be V2 format; check LOCKFILES in policy.h",
+	      zpath);
+#endif
+#endif /* DEBUG > 0 */
+
 #if HAVE_QNX_LOCKFILES
       ab[cgot] = '\0';
       ipid = (pid_t) strtol (ab, &zend, 10);
@@ -308,17 +327,23 @@ fsdo_lock (zlock, fspooldir, pferr)
 	    }
 	}
 
+      /* If the lock file is empty (cgot == 0), we assume that it is
+         stale.  This can happen if the system crashed after the lock
+         file was created but before the process ID was written out.  */
+      if (cgot > 0)
+	{
 #if HAVE_QNX_LOCKFILES
-      if (! fsqnx_stale ((unsigned long) ipid, (unsigned long) inme,
-			 (unsigned long) inid, pferr))
-	break;
+	  if (! fsqnx_stale ((unsigned long) ipid, (unsigned long) inme,
+			     (unsigned long) inid, pferr))
+	    break;
 #else
-      /* If the process still exists, we will get EPERM rather than
-	 ESRCH.  We then return FALSE to indicate that we cannot make
-	 the lock.  */
-      if (kill (ipid, 0) == 0 || errno == EPERM)
-	break;
+	  /* If the process still exists, we will get EPERM rather
+	     than ESRCH.  We then return FALSE to indicate that we
+	     cannot make the lock.  */
+	  if (kill (ipid, 0) == 0 || errno == EPERM)
+	    break;
 #endif
+	}
 
       if (fstat (o, &st) < 0)
 	strcpy (abtime, "unknown");
@@ -399,7 +424,11 @@ fsdo_lock (zlock, fspooldir, pferr)
 	{
 	  (void) close (o);
 	  o = -1;
-	  (void) remove (zpath);
+	  if (remove (zpath) != 0)
+	    {
+	      zerr = "remove";
+	      break;
+	    }
 	  fret = TRUE;
 	  continue;
 	}
@@ -411,7 +440,7 @@ fsdo_lock (zlock, fspooldir, pferr)
 	}
 
 #if HAVE_QNX_LOCKFILES
-      sprintf (ab, "%10ld %10ld\n", (long) ime, (long) inid);
+      sprintf (ab, "%10ld %10ld\n", (long) ime, (long) inme);
       cwrote = write (o, ab, strlen (ab));
 #else
 #if HAVE_V2_LOCKFILES
