@@ -1,7 +1,7 @@
 /* spool.c
    Find a file in the spool directory.
 
-   Copyright (C) 1991, 1992, 1993 Ian Lance Taylor
+   Copyright (C) 1991, 1992, 1993, 2002 Ian Lance Taylor
 
    This file is part of the Taylor UUCP package.
 
@@ -17,16 +17,15 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307, USA.
 
-   The author of the program may be contacted at ian@airs.com or
-   c/o Cygnus Support, 48 Grove Street, Somerville, MA 02144.
+   The author of the program may be contacted at ian@airs.com.
    */
 
 #include "uucp.h"
 
 #if USE_RCS_ID
-const char spool_rcsid[] = "$Id: spool.c,v 1.11 1995/06/30 21:22:54 ian Rel $";
+const char spool_rcsid[] = "$Id: spool.c,v 1.14 2002/03/05 19:10:42 ian Rel $";
 #endif
 
 #include "uudefs.h"
@@ -194,7 +193,7 @@ char *
 zsfind_file (zsimple, zsystem, bgrade)
      const char *zsimple;
      const char *zsystem;
-     int bgrade;
+     int bgrade ATTRIBUTE_UNUSED;
 {
   /* zsysdep_spool_commands calls this with TMPXXX which we must treat
      as a C. file.  */
