@@ -1,7 +1,7 @@
 /* bool.c
    Parse a boolean string into a variable.
 
-   Copyright (C) 1992 Ian Lance Taylor
+   Copyright (C) 1992, 2002 Ian Lance Taylor
 
    This file is part of the Taylor UUCP uuconf library.
 
@@ -17,16 +17,15 @@
 
    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307, USA.
 
-   The author of the program may be contacted at ian@airs.com or
-   c/o Cygnus Support, 48 Grove Street, Somerville, MA 02144.
+   The author of the program may be contacted at ian@airs.com.
    */
 
 #include "uucnfi.h"
 
 #if USE_RCS_ID
-const char _uuconf_bool_rcsid[] = "$Id: bool.c,v 1.5 1995/06/21 19:21:39 ian Rel $";
+const char _uuconf_bool_rcsid[] = "$Id: bool.c,v 1.8 2002/03/05 19:10:42 ian Rel $";
 #endif
 
 /* Parse a boolean string into a variable.  This is called by
@@ -35,10 +34,9 @@ const char _uuconf_bool_rcsid[] = "$Id: bool.c,v 1.5 1995/06/21 19:21:39 ian Rel
    error code, including both UUCONF_CMDTABRET_KEEP and
    UUCONF_CMDTABRET_EXIT if appropriate.  */
 
-/*ARGSIGNORED*/
 int
 _uuconf_iboolean (qglobal, zval, pi)
-     struct sglobal *qglobal;
+     struct sglobal *qglobal ATTRIBUTE_UNUSED;
      const char *zval;
      boolean *pi;
 {
