@@ -1,7 +1,7 @@
 /* chatc.c
    Subroutines to handle chat script commands.
 
-   Copyright (C) 1992 Ian Lance Taylor
+   Copyright (C) 1992, 2002 Ian Lance Taylor
 
    This file is part of the Taylor UUCP uuconf library.
 
@@ -17,16 +17,15 @@
 
    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307, USA.
 
-   The author of the program may be contacted at ian@airs.com or
-   c/o Cygnus Support, 48 Grove Street, Somerville, MA 02144.
+   The author of the program may be contacted at ian@airs.com.
    */
 
 #include "uucnfi.h"
 
 #if USE_RCS_ID
-const char _uuconf_chatc_rcsid[] = "$Id: chatc.c,v 1.6 1995/06/21 19:21:48 ian Rel $";
+const char _uuconf_chatc_rcsid[] = "$Id: chatc.c,v 1.10 2002/03/05 19:10:42 ian Rel $";
 #endif
 
 #include <ctype.h>
@@ -91,6 +90,13 @@ _uuconf_ichat_cmd (qglobal, argc, argv, qchat, pblock)
 
   iret = uuconf_cmd_args ((pointer) qglobal, argc, argv, as, pblock,
 			  icunknown, 0, pblock);
+
+  /* If chat-program was specified with no arguments, treat that as no
+     chat-program.  This may be used to override an earlier
+     chat-program.  There is a space leak here.  */
+  if (qchat->uuconf_pzprogram != NULL && qchat->uuconf_pzprogram[0] == NULL)
+    qchat->uuconf_pzprogram = NULL;
+
   return iret &~ UUCONF_CMDTABRET_EXIT;
 }
 
@@ -175,7 +181,7 @@ icchat (pglobal, argc, argv, pvar, pinfo)
 static int
 icchat_fail (pglobal, argc, argv, pvar, pinfo)
      pointer pglobal;
-     int argc;
+     int argc ATTRIBUTE_UNUSED;
      char **argv;
      pointer pvar;
      pointer pinfo;
@@ -192,11 +198,11 @@ icchat_fail (pglobal, argc, argv, pvar, pinfo)
 /*ARGSUSED*/
 static int
 icunknown (pglobal, argc, argv, pvar, pinfo)
-     pointer pglobal;
-     int argc;
-     char **argv;
-     pointer pvar;
-     pointer pinfo;
+     pointer pglobal ATTRIBUTE_UNUSED;
+     int argc ATTRIBUTE_UNUSED;
+     char **argv ATTRIBUTE_UNUSED;
+     pointer pvar ATTRIBUTE_UNUSED;
+     pointer pinfo ATTRIBUTE_UNUSED;
 {
   return UUCONF_SYNTAX_ERROR;
 }
