@@ -1,7 +1,7 @@
 /* freprt.c
    Free port information.
 
-   Copyright (C) 1992 Ian Lance Taylor
+   Copyright (C) 1992, 2002 Ian Lance Taylor
 
    This file is part of the Taylor UUCP uuconf library.
 
@@ -17,16 +17,15 @@
 
    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307, USA.
 
-   The author of the program may be contacted at ian@airs.com or
-   c/o Cygnus Support, 48 Grove Street, Somerville, MA 02144.
+   The author of the program may be contacted at ian@airs.com.
    */
 
 #include "uucnfi.h"
 
 #if USE_RCS_ID
-const char _uuconf_freprt_rcsid[] = "$Id: freprt.c,v 1.5 1995/06/21 19:22:33 ian Rel $";
+const char _uuconf_freprt_rcsid[] = "$Id: freprt.c,v 1.8 2002/03/05 19:10:42 ian Rel $";
 #endif
 
 /* Free the memory allocated for a port.  */
@@ -36,7 +35,7 @@ const char _uuconf_freprt_rcsid[] = "$Id: freprt.c,v 1.5 1995/06/21 19:22:33 ian
 /*ARGSUSED*/
 int
 uuconf_port_free (pglobal, qport)
-     pointer pglobal;
+     pointer pglobal ATTRIBUTE_UNUSED;
      struct uuconf_port *qport;
 {
   uuconf_free_block (qport->uuconf_palloc);
