@@ -1,7 +1,7 @@
 /* hport.c
    Find a port in the HDB configuration files.
 
-   Copyright (C) 1992, 1993 Ian Lance Taylor
+   Copyright (C) 1992, 1993, 2002 Ian Lance Taylor
 
    This file is part of the Taylor UUCP uuconf library.
 
@@ -17,16 +17,15 @@
 
    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307, USA.
 
-   The author of the program may be contacted at ian@airs.com or
-   c/o Cygnus Support, 48 Grove Street, Somerville, MA 02144.
+   The author of the program may be contacted at ian@airs.com.
    */
 
 #include "uucnfi.h"
 
 #if USE_RCS_ID
-const char _uuconf_hport_rcsid[] = "$Id: hport.c,v 1.14 1995/06/21 19:22:58 ian Rel $";
+const char _uuconf_hport_rcsid[] = "$Id: hport.c,v 1.18 2002/03/05 19:10:42 ian Rel $";
 #endif
 
 #include <errno.h>
@@ -40,7 +39,7 @@ uuconf_hdb_find_port (pglobal, zname, ibaud, ihighbaud, pifn, pinfo, qport)
      pointer pglobal;
      const char *zname;
      long ibaud;
-     long ihighbaud;
+     long ihighbaud ATTRIBUTE_UNUSED;
      int (*pifn) P((struct uuconf_port *, pointer));
      pointer pinfo;
      struct uuconf_port *qport;
@@ -217,6 +216,7 @@ uuconf_hdb_find_port (pglobal, zname, ibaud, ihighbaud, pifn, pinfo, qport)
 		   | UUCONF_RELIABLE_EIGHT | UUCONF_RELIABLE_FULLDUPLEX
 		   | UUCONF_RELIABLE_SPECIFIED);
 	      qport->uuconf_u.uuconf_stcp.uuconf_zport = pzsplit[1];
+	      qport->uuconf_u.uuconf_stcp.uuconf_iversion = 0;
 	      ppzdialer = &qport->uuconf_u.uuconf_stcp.uuconf_pzdialer;
 	    }
 	  else if (ctoks >= 5
