@@ -1,7 +1,7 @@
 /* remunk.c
    Get the name of the remote.unknown shell script.
 
-   Copyright (C) 1992, 1993 Ian Lance Taylor
+   Copyright (C) 1992, 1993, 2002 Ian Lance Taylor
 
    This file is part of the Taylor UUCP uuconf library.
 
@@ -17,16 +17,15 @@
 
    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307, USA.
 
-   The author of the program may be contacted at ian@airs.com or
-   c/o Cygnus Support, 48 Grove Street, Somerville, MA 02144.
+   The author of the program may be contacted at ian@airs.com.
    */
 
 #include "uucnfi.h"
 
 #if USE_RCS_ID
-const char _uuconf_remunk_rcsid[] = "$Id: remunk.c,v 1.5 1995/06/21 19:23:59 ian Rel $";
+const char _uuconf_remunk_rcsid[] = "$Id: remunk.c,v 1.8 2002/03/05 19:10:42 ian Rel $";
 #endif
 
 /* Get the name of the remote.unknown shell script.  */
@@ -34,8 +33,8 @@ const char _uuconf_remunk_rcsid[] = "$Id: remunk.c,v 1.5 1995/06/21 19:23:59 ian
 /*ARGSUSED*/
 int
 uuconf_remote_unknown (pglobal, pzname)
-     pointer pglobal;
-     char **pzname;
+     pointer pglobal ATTRIBUTE_UNUSED;
+     char **pzname ATTRIBUTE_UNUSED;
 {
 #if ! HAVE_HDB_CONFIG
   return UUCONF_NOT_FOUND;
